@@ -9,13 +9,12 @@
 # 231-239.
 # M. Lau July 2011
 # ---------------------------------------------------
-as.extended <-
-function(x='network object',zero.na=TRUE){
 
-                                          #Check for network class object
+as.extended <- function(x,zero.na=TRUE){
+
+                                        #Check for network class object
   if (class(x) != "network"){warning('x is not a network class object')}
-           
-                             #unpack the data from the network object
+                                        #unpack the data from the network object
   flow <- x%n%'flow'
   input <- x%v%'input'
   respiration <- x%v%'respiration'
@@ -25,9 +24,8 @@ function(x='network object',zero.na=TRUE){
   x <- cbind(flow,export,respiration,rep(0,nrow(flow)))
   x <- rbind(x,rep(0,length(import)),rep(0,length(import)),import)
                                         #make NA values zero if zero.na == TRUE
-  if (zero.na == TRUE){
-   x[is.na(x)] = 0 
+  if (zero.na){
+    x[is.na(x)] = 0 
   }
   return(x)
-
 }
