@@ -5,9 +5,9 @@
 # M. Lau 1 Oct 2012
 # ---------------------------------------------------
 
-force.balance <- function(x='network object',tol=5,max.itr=10,method='AVG2'){
+force.balance <- function(x,tol=5,max.itr=10,method='AVG2'){
   n.itr <- 1 # initiate counter
-  while(ssCheck(x)==FALSE&n.itr<max.itr){
+  while(ssCheck(x)==FALSE & n.itr<max.itr){
     x <- balance(x,method=method)
     n.itr <- n.itr + 1
   }
