@@ -7,21 +7,25 @@
 read.wand <- function(file='file name with path'){
                                         # file is the full excel file name
                                         # asssumes that first sheet is "Main" and second sheet is "Flows".
-  d1 <- read.xlsx(file,sheetName="Main",rowIndex=1:8,colIndex=1)
-  n <- as.numeric(as.character(d1$Network.Analysis[3]))
-  dat.main <- read.xlsx(file,sheetName="Main",rowIndex=9:(n+9),colIndex=1:6)
-  dat.main[is.na(dat.main)] <- 0
-  dat.main$Compartments.Names <- as.character(dat.main$Compartments.Names)  # convert to strings
+  x <- as.matrix(read.xlsx(file,sheetName="Main"))
+  d1 <- x[1:8,1] #model info
+  n <- as.numeric(as.character(d1[3])) #Number of compartments
+  dat.main <- x[9:(n+9),2:6] #isolate the stocks,imports,exports,respirations
+  dat.main[is.na(dat.main)] <- 0 #zero NA
+  vn <- dat.main[1:n,1] #vertex names
+  dat.main <- apply(dat.main[,2:5],2,as.numeric)
                                         # get flows
-  F <- read.xlsx(file,sheetName="Flows",rowIndex=1:(n+1),colIndex=1:(n+1))
-  flow.mat <- as.matrix(F[1:n,2:(n+1)])
+  F <- read.xlsx(file,sheetName="Flows")
+  flow.mat <- as.matrix(F[1:(n),2:(n+1)])
   flow.mat[is.na(flow.mat)] <- 0
-
+  flow.mat <- apply(flow.mat,2,as.numeric)
+  rownames(flow.mat) <- colnames(flow.mat) <- vn
+                                        #pack for export
   x <- list('flow'=flow.mat,
-    'input'=dat.main$Imports,
-    'exports'=dat.main$Exports,
-    'respiration'=dat.main$Respirations,
-    'storage'=dat.main$Standing.Stocks)
+    'input'=dat.main[,2],
+    'exports'=dat.main[,3],
+    'respiration'=dat.main[,4],
+    'storage'=dat.main[,1])
   ## --- Create Network Object From Data ---
   y <- network(x[[1]],directed=TRUE)
                                         # packing up the attributes into the network object (y)
@@ -30,9 +34,7 @@ read.wand <- function(file='file name with path'){
   set.vertex.attribute(y,'respiration',x[[4]])
   set.vertex.attribute(y,'storage',x[[5]])
   set.vertex.attribute(y,'output',x[[3]]+x[[4]])
-  y%v%'vertex.names' <- dat.main$Compartments.Names
-  rownames(flow.mat) <- dat.main$Compartments.Names
-  colnames(flow.mat) <- rownames(flow.mat)
+  y%v%'vertex.names' <- vn
   y%n%'flow' <- flow.mat
   return(y)
 }
